import { __extends } from "tslib";
import { HorizontalAlignment_$type } from "igniteui-react-core";
import { VerticalAlignment_$type } from "igniteui-react-core";
import { Visibility_$type } from "igniteui-react-core";
import { ValueAxisLabelLocation_$type } from "./ValueAxisLabelLocation";
import { AngleAxisLabelLocation_$type } from "./AngleAxisLabelLocation";
import { IgrDomainChart } from "./igr-domain-chart";
import { brushToString, stringToBrush, ensureBool, ensureEnum, arrayFindByName } from "igniteui-react-core";
/**
 * Represents a base class for domain charts with X/Y axes
*/
var IgrRadialBaseChart = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialBaseChart, _super);
    function IgrRadialBaseChart(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrRadialBaseChart.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisFormatLabel", {
        /**
         * Gets or sets function which takes an context object and returns a formatted label for the X-axis.
        */
        get: function () {
            return this.i.aa0;
        },
        set: function (v) {
            this.i.aa0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisFormatLabel", {
        /**
         * Gets or sets function which takes a context object and returns a formatted label for the Y-axis.
        */
        get: function () {
            return this.i.aa1;
        },
        set: function (v) {
            this.i.aa1 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelLeftMargin", {
        /**
         * Gets or sets the left margin of labels on the X-axis
        */
        get: function () {
            return this.i.acf;
        },
        set: function (v) {
            this.i.acf = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelTopMargin", {
        /**
         * Gets or sets the top margin of labels on the X-axis
        */
        get: function () {
            return this.i.ach;
        },
        set: function (v) {
            this.i.ach = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelRightMargin", {
        /**
         * Gets or sets the right margin of labels on the X-axis
        */
        get: function () {
            return this.i.acg;
        },
        set: function (v) {
            this.i.acg = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelBottomMargin", {
        /**
         * Gets or sets the bottom margin of labels on the X-axis
        */
        get: function () {
            return this.i.ace;
        },
        set: function (v) {
            this.i.ace = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelLeftMargin", {
        /**
         * Gets or sets the left margin of labels on the Y-axis
        */
        get: function () {
            return this.i.ac2;
        },
        set: function (v) {
            this.i.ac2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelTopMargin", {
        /**
         * Gets or sets the top margin of labels on the Y-axis
        */
        get: function () {
            return this.i.ac4;
        },
        set: function (v) {
            this.i.ac4 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelRightMargin", {
        /**
         * Gets or sets the right margin of labels on the Y-axis
        */
        get: function () {
            return this.i.ac3;
        },
        set: function (v) {
            this.i.ac3 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelBottomMargin", {
        /**
         * Gets or sets the bottom margin of labels on the Y-axis
        */
        get: function () {
            return this.i.ac1;
        },
        set: function (v) {
            this.i.ac1 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelTextColor", {
        /**
         * Gets or sets color of labels on the X-axis
        */
        get: function () {
            return brushToString(this.i.ahf);
        },
        set: function (v) {
            this.i.ahf = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelTextColor", {
        /**
         * Gets or sets color of labels on the Y-axis
        */
        get: function () {
            return brushToString(this.i.ahm);
        },
        set: function (v) {
            this.i.ahm = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "actualAngleAxisLabelTextColor", {
        /**
         * Gets the actual color of labels on the X-axis
        */
        get: function () {
            return brushToString(this.i.ahd);
        },
        set: function (v) {
            this.i.ahd = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "actualValueAxisLabelTextColor", {
        /**
         * Gets the actual color of labels on the Y-axis
        */
        get: function () {
            return brushToString(this.i.ahe);
        },
        set: function (v) {
            this.i.ahe = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleMargin", {
        /**
         * Gets or sets the margin around a title on the X-axis
        */
        get: function () {
            return this.i.acs;
        },
        set: function (v) {
            this.i.acs = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleMargin", {
        /**
         * Gets or sets the margin around a title on the Y-axis
        */
        get: function () {
            return this.i.adf;
        },
        set: function (v) {
            this.i.adf = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleLeftMargin", {
        /**
         * Gets or sets the left margin of a title on the X-axis
        */
        get: function () {
            return this.i.acr;
        },
        set: function (v) {
            this.i.acr = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleLeftMargin", {
        /**
         * Gets or sets the left margin of a title on the Y-axis
        */
        get: function () {
            return this.i.ade;
        },
        set: function (v) {
            this.i.ade = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleTopMargin", {
        /**
         * Gets or sets the top margin of a title on the X-axis
        */
        get: function () {
            return this.i.acu;
        },
        set: function (v) {
            this.i.acu = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleTopMargin", {
        /**
         * Gets or sets the top margin of a title on the Y-axis
        */
        get: function () {
            return this.i.adh;
        },
        set: function (v) {
            this.i.adh = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleRightMargin", {
        /**
         * Gets or sets the right margin of a title on the X-axis
        */
        get: function () {
            return this.i.act;
        },
        set: function (v) {
            this.i.act = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleRightMargin", {
        /**
         * Gets or sets the right margin of a title on the Y-axis
        */
        get: function () {
            return this.i.adg;
        },
        set: function (v) {
            this.i.adg = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleBottomMargin", {
        /**
         * Gets or sets the bottom margin of a title on the X-axis
        */
        get: function () {
            return this.i.acq;
        },
        set: function (v) {
            this.i.acq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleBottomMargin", {
        /**
         * Gets or sets the bottom margin of a title on the Y-axis
        */
        get: function () {
            return this.i.add;
        },
        set: function (v) {
            this.i.add = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleTextColor", {
        /**
         * Gets or sets color of title on the X-axis
        */
        get: function () {
            return brushToString(this.i.ahl);
        },
        set: function (v) {
            this.i.ahl = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleTextColor", {
        /**
         * Gets or sets color of title on the Y-axis
        */
        get: function () {
            return brushToString(this.i.ahs);
        },
        set: function (v) {
            this.i.ahs = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelTextStyle", {
        /**
         * Gets or sets CSS font property for labels on X-axis
        */
        get: function () {
            return this.i.aea;
        },
        set: function (v) {
            this.i.aea = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelTextStyle", {
        /**
         * Gets or sets CSS font property for labels on Y-axis
        */
        get: function () {
            return this.i.afi;
        },
        set: function (v) {
            this.i.afi = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleTextStyle", {
        /**
         * Gets or sets CSS font property for title on X-axis
        */
        get: function () {
            return this.i.ae0;
        },
        set: function (v) {
            this.i.ae0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleTextStyle", {
        /**
         * Gets or sets CSS font property for title on Y-axis
        */
        get: function () {
            return this.i.af8;
        },
        set: function (v) {
            this.i.af8 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabel", {
        /**
         * Gets or sets the format for labels along the X-axis.
        */
        get: function () {
            return this.i.adk;
        },
        set: function (v) {
            this.i.adk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabel", {
        /**
         * Gets or sets the property or string from which the labels are derived.
        */
        get: function () {
            return this.i.adl;
        },
        set: function (v) {
            this.i.adl = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisMajorStroke", {
        /**
         * Gets or sets the color to apply to major gridlines along the X-axis.
        */
        get: function () {
            return brushToString(this.i.ahg);
        },
        set: function (v) {
            this.i.ahg = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisMajorStroke", {
        /**
         * Gets or sets the color to apply to major gridlines along the Y-axis.
        */
        get: function () {
            return brushToString(this.i.ahn);
        },
        set: function (v) {
            this.i.ahn = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisMajorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to major gridlines along the X-axis.
        */
        get: function () {
            return this.i.aci;
        },
        set: function (v) {
            this.i.aci = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisMajorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to major gridlines along the Y-axis.
        */
        get: function () {
            return this.i.ac5;
        },
        set: function (v) {
            this.i.ac5 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisMinorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to minor gridlines along the X-axis.
        */
        get: function () {
            return this.i.acl;
        },
        set: function (v) {
            this.i.acl = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisMinorStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to minor gridlines along the Y-axis.
        */
        get: function () {
            return this.i.ac8;
        },
        set: function (v) {
            this.i.ac8 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisStrip", {
        /**
         * Gets or sets the color to apply to stripes along the X-axis.
        */
        get: function () {
            return brushToString(this.i.ahi);
        },
        set: function (v) {
            this.i.ahi = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisStrip", {
        /**
         * Gets or sets the color to apply to stripes along the Y-axis.
        */
        get: function () {
            return brushToString(this.i.ahp);
        },
        set: function (v) {
            this.i.ahp = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisStroke", {
        /**
         * Gets or sets the color to apply to the X-axis line.
        */
        get: function () {
            return brushToString(this.i.ahj);
        },
        set: function (v) {
            this.i.ahj = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisStroke", {
        /**
         * Gets or sets the color to apply to the Y-axis line.
        */
        get: function () {
            return brushToString(this.i.ahq);
        },
        set: function (v) {
            this.i.ahq = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to the X-axis line.
        */
        get: function () {
            return this.i.acm;
        },
        set: function (v) {
            this.i.acm = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to the Y-axis line.
        */
        get: function () {
            return this.i.ac9;
        },
        set: function (v) {
            this.i.ac9 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTickLength", {
        /**
         * Gets or sets the length of tickmarks along the X-axis.
        */
        get: function () {
            return this.i.acn;
        },
        set: function (v) {
            this.i.acn = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTickLength", {
        /**
         * Gets or sets the length of tickmarks along the Y-axis.
        */
        get: function () {
            return this.i.ada;
        },
        set: function (v) {
            this.i.ada = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTickStroke", {
        /**
         * Gets or sets the color to apply to tickmarks along the X-axis.
        */
        get: function () {
            return brushToString(this.i.ahk);
        },
        set: function (v) {
            this.i.ahk = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTickStroke", {
        /**
         * Gets or sets the color to apply to tickmarks along the Y-axis.
        */
        get: function () {
            return brushToString(this.i.ahr);
        },
        set: function (v) {
            this.i.ahr = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTickStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to tickmarks along the X-axis.
        */
        get: function () {
            return this.i.aco;
        },
        set: function (v) {
            this.i.aco = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTickStrokeThickness", {
        /**
         * Gets or sets the thickness to apply to tickmarks along the Y-axis.
        */
        get: function () {
            return this.i.adb;
        },
        set: function (v) {
            this.i.adb = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitle", {
        /**
         * Gets or sets the Text to display below the X-axis.
        */
        get: function () {
            return this.i.aer;
        },
        set: function (v) {
            this.i.aer = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitle", {
        /**
         * Gets or sets the Text to display to the left of the Y-axis.
        */
        get: function () {
            return this.i.afz;
        },
        set: function (v) {
            this.i.afz = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisMinorStroke", {
        /**
         * Gets or sets the color to apply to minor gridlines along the X-axis.
        */
        get: function () {
            return brushToString(this.i.ahh);
        },
        set: function (v) {
            this.i.ahh = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisMinorStroke", {
        /**
         * Gets or sets the color to apply to minor gridlines along the Y-axis.
        */
        get: function () {
            return brushToString(this.i.aho);
        },
        set: function (v) {
            this.i.aho = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelAngle", {
        /**
         * Gets or sets the angle of rotation for labels along the X-axis.
        */
        get: function () {
            return this.i.acd;
        },
        set: function (v) {
            this.i.acd = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelAngle", {
        /**
         * Gets or sets the angle of rotation for labels along the Y-axis.
        */
        get: function () {
            return this.i.ac0;
        },
        set: function (v) {
            this.i.ac0 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisExtent", {
        /**
         * Gets or sets the distance between the X-axis and the bottom of the chart.
        */
        get: function () {
            return this.i.acc;
        },
        set: function (v) {
            this.i.acc = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisMaximumExtent", {
        /**
         * Gets or sets the maximum distance between the X-axis and the bottom of the chart.
        */
        get: function () {
            return this.i.acj;
        },
        set: function (v) {
            this.i.acj = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisMaximumExtentPercentage", {
        /**
         * Gets or sets the maximum width between the X-axis and the bottom of the chart, as a percentage of total chart width.
        */
        get: function () {
            return this.i.ack;
        },
        set: function (v) {
            this.i.ack = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisExtent", {
        /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        */
        get: function () {
            return this.i.acz;
        },
        set: function (v) {
            this.i.acz = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisMaximumExtent", {
        /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        */
        get: function () {
            return this.i.ac6;
        },
        set: function (v) {
            this.i.ac6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisMaximumExtentPercentage", {
        /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        */
        get: function () {
            return this.i.ac7;
        },
        set: function (v) {
            this.i.ac7 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleAngle", {
        /**
         * Gets or sets the angle of rotation for the X-axis title.
        */
        get: function () {
            return this.i.acp;
        },
        set: function (v) {
            this.i.acp = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleAngle", {
        /**
         * Gets or sets the angle of rotation for the Y-axis title.
        */
        get: function () {
            return this.i.adc;
        },
        set: function (v) {
            this.i.adc = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisInverted", {
        /**
         * Gets or sets whether to invert the direction of the X-axis by placing the first data items on the right side of the chart.
        */
        get: function () {
            return this.i.aa8;
        },
        set: function (v) {
            this.i.aa8 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisInverted", {
        /**
         * Gets or sets whether to invert the direction of the Y-axis by placing the minimum numeric value at the top of the chart.
        */
        get: function () {
            return this.i.aa9;
        },
        set: function (v) {
            this.i.aa9 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisTitleAlignment", {
        /**
         * Gets or sets Horizontal alignment of the X-axis title.
        */
        get: function () {
            return this.i.agv;
        },
        set: function (v) {
            this.i.agv = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisTitleAlignment", {
        /**
         * Gets or sets Vertical alignment of the Y-axis title.
        */
        get: function () {
            return this.i.ahy;
        },
        set: function (v) {
            this.i.ahy = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelHorizontalAlignment", {
        /**
         * Gets or sets Horizontal alignment of X-axis labels.
        */
        get: function () {
            return this.i.agu;
        },
        set: function (v) {
            this.i.agu = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelHorizontalAlignment", {
        /**
         * Gets or sets Horizontal alignment of Y-axis labels.
        */
        get: function () {
            return this.i.agw;
        },
        set: function (v) {
            this.i.agw = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelVerticalAlignment", {
        /**
         * Gets or sets Vertical alignment of X-axis labels.
        */
        get: function () {
            return this.i.ahw;
        },
        set: function (v) {
            this.i.ahw = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelVerticalAlignment", {
        /**
         * Gets or sets Vertical alignment of Y-axis labels.
        */
        get: function () {
            return this.i.ahx;
        },
        set: function (v) {
            this.i.ahx = ensureEnum(VerticalAlignment_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelVisibility", {
        /**
         * Gets or sets Visibility of X-axis labels.
        */
        get: function () {
            return this.i.ah1;
        },
        set: function (v) {
            this.i.ah1 = ensureEnum(Visibility_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelVisibility", {
        /**
         * Gets or sets Visibility of Y-axis labels.
        */
        get: function () {
            return this.i.ah2;
        },
        set: function (v) {
            this.i.ah2 = ensureEnum(Visibility_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelLocation", {
        /**
         * Gets or sets location of Y-axis labels, relative to the plot area.
        */
        get: function () {
            return this.i.aa5;
        },
        set: function (v) {
            this.i.aa5 = ensureEnum(ValueAxisLabelLocation_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelLocation", {
        /**
         * Gets or sets location of X-axis labels, relative to the plot area.
        */
        get: function () {
            return this.i.aav;
        },
        set: function (v) {
            this.i.aav = ensureEnum(AngleAxisLabelLocation_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelFormat", {
        /**
         * Gets or sets the format string for the X axis label.
        */
        get: function () {
            return this.i.ad1;
        },
        set: function (v) {
            this.i.ad1 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "angleAxisLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the AngleAxisLabelFormat string.
        */
        get: function () {
            return this.i.aas;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.aas = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelFormat", {
        /**
         * Gets or sets the format string for the Y axis label.
        */
        get: function () {
            return this.i.ae9;
        },
        set: function (v) {
            this.i.ae9 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBaseChart.prototype, "valueAxisLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the ValueAxisLabelFormat string.
        */
        get: function () {
            return this.i.aat;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.aat = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrRadialBaseChart.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.angleAxisLabelFormatSpecifiers != null && arrayFindByName(this.angleAxisLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.angleAxisLabelFormatSpecifiers, name);
        }
        if (this.valueAxisLabelFormatSpecifiers != null && arrayFindByName(this.valueAxisLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.valueAxisLabelFormatSpecifiers, name);
        }
        return null;
    };
    /**
     * Called by the UI framework to provide a UI container for rendering this control.
    
    * @param container  * The UI container element.
    */
    IgrRadialBaseChart.prototype.provideContainer = function (container) {
        this.i.provideContainer(container);
    };
    /**
     * Converts the given visual location to a data value.
    
    * @param unscaledValue  * The x-coordinate of the location to scale.
    */
    IgrRadialBaseChart.prototype.getScaledAngle = function (unscaledValue) {
        var iv = this.i.acv(unscaledValue);
        return (iv);
    };
    /**
     * Converts the given data value to a visual location.
    
    * @param scaledValue  * The data value to un-scale.
    */
    IgrRadialBaseChart.prototype.getUnscaledAngle = function (scaledValue) {
        var iv = this.i.acx(scaledValue);
        return (iv);
    };
    /**
     * Converts the given visual location to a data value.
    
    * @param unscaledValue  * The y-coordinate of the location to scale.
    */
    IgrRadialBaseChart.prototype.getScaledValue = function (unscaledValue) {
        var iv = this.i.acw(unscaledValue);
        return (iv);
    };
    /**
     * Converts the given data value to a visual location.
    
    * @param scaledValue  * The data value to un-scale.
    */
    IgrRadialBaseChart.prototype.getUnscaledValue = function (scaledValue) {
        var iv = this.i.acy(scaledValue);
        return (iv);
    };
    return IgrRadialBaseChart;
}(IgrDomainChart));
export { IgrRadialBaseChart };
